import { useEffect } from "react";
import { Link } from "react-router-dom";
import { useMedia } from "../contexts/MediaContext";
import { useAuth } from "../contexts/AuthContext";
import MediaCarousel from "../components/media/MediaCarousel";
import { FiTrendingUp, FiCalendar, FiAward } from "react-icons/fi";
import { getImageUrl } from "../services/tmdbApi";

function HomePage() {
  const { fetchTrendingMedia, trendingMovies, trendingTvShows, loading } =
    useMedia();
  const { currentUser } = useAuth();

  useEffect(() => {
    fetchTrendingMedia();
  }, [fetchTrendingMedia]);

  // Get featured media (first trending movie with backdrop)
  const featuredMedia =
    trendingMovies.find((movie) => movie.backdrop_path) || trendingMovies[0];

  return (
    <div className="pt-20">
      {/* Hero Section */}
      {featuredMedia && (
        <div className="relative w-full h-[500px] md:h-[600px] overflow-hidden">
          <div className="absolute inset-0">
            <img
              src={getImageUrl(featuredMedia.backdrop_path, "original")}
              alt={featuredMedia.title}
              className="w-full h-full object-cover"
            />
            <div className="absolute inset-0 bg-gradient-to-t from-campfire-dark via-campfire-dark/60 to-transparent"></div>
          </div>

          <div className="container-custom relative h-full flex flex-col justify-end pb-16">
            <span className="inline-flex items-center px-3 py-1 rounded-full text-xs font-medium bg-campfire-amber text-campfire-dark mb-4">
              <FiTrendingUp className="mr-1" /> Trending
            </span>
            <h1 className="text-4xl md:text-5xl font-bold mb-4 max-w-2xl">
              {featuredMedia.title}
            </h1>
            <p className="text-campfire-ash mb-6 max-w-2xl">
              {featuredMedia.overview.substring(0, 200)}...
            </p>
            <Link
              to={`/media/${featuredMedia.id}?type=movie`}
              className="btn-primary inline-flex items-center"
            >
              View Details
            </Link>
          </div>
        </div>
      )}

      {/* Welcome Message for Logged In Users */}
      {currentUser && (
        <div className="container-custom my-8">
          <div className="bg-campfire-charcoal rounded-lg p-6">
            <h2 className="text-2xl font-bold mb-2">
              С возвращением, {currentUser.username}!
            </h2>
            <p className="text-campfire-ash mb-4">
              Продолжайте открывать отличный контент и делиться своими мыслями с
              сообществом.
            </p>
            <Link
              to={`/profile/${currentUser.uid}`}
              className="text-campfire-amber hover:text-campfire-ember"
            >
              Перейти в профиль →
            </Link>
          </div>
        </div>
      )}

      {/* Main Content */}
      <div className="container-custom py-8">
        {loading ? (
          <div className="flex justify-center items-center h-64">
            <div className="animate-spin rounded-full h-12 w-12 border-t-2 border-b-2 border-campfire-amber"></div>
          </div>
        ) : (
          <>
            {/* Trending Movies */}
            <div className="mb-12">
              <div className="flex items-center mb-2">
                <FiTrendingUp className="text-campfire-amber mr-2" size={20} />
                <h2 className="text-2xl font-bold">Фильмы</h2>
              </div>
              <MediaCarousel
                media={trendingMovies}
                mediaType="movie"
                seeAllLink="/discover/movies"
              />
            </div>

            {/* Trending TV Shows */}
            <div className="mb-12">
              <div className="flex items-center mb-2">
                <FiTrendingUp className="text-campfire-amber mr-2" size={20} />
                <h2 className="text-2xl font-bold">Сериалы</h2>
              </div>
              <MediaCarousel
                media={trendingTvShows}
                mediaType="tv"
                seeAllLink="/discover/tv"
              />
            </div>

            {/* Latest Reviews */}
            <div className="mb-12">
              <div className="flex items-center mb-6">
                <FiCalendar className="text-campfire-amber mr-2" size={20} />
                <h2 className="text-2xl font-bold">Последние рецензии</h2>
              </div>
              <div className="grid grid-cols-1 md:grid-cols-2 gap-6">
                {/* Placeholder for latest reviews */}
                <div className="bg-campfire-charcoal rounded-lg p-6 flex flex-col items-center justify-center text-center h-48">
                  <p className="text-campfire-ash mb-4">Рецензий пока нет</p>
                  {!currentUser && (
                    <Link
                      to="/login"
                      className="text-campfire-amber hover:text-campfire-ember"
                    >
                      Войдите, чтобы написать рецензию
                    </Link>
                  )}
                </div>
                <div className="bg-campfire-charcoal rounded-lg p-6 flex flex-col items-center justify-center text-center h-48">
                  <p className="text-campfire-ash mb-4">Рецензий пока нет</p>
                  {!currentUser && (
                    <Link
                      to="/login"
                      className="text-campfire-amber hover:text-campfire-ember"
                    >
                      Войдите, чтобы написать рецензию
                    </Link>
                  )}
                </div>
              </div>
            </div>

            {/* Critic's Choice */}
            <div className="mb-12">
              <div className="flex items-center mb-6">
                <FiAward className="text-campfire-amber mr-2" size={20} />
                <h2 className="text-2xl font-bold">Выбор Резидентов</h2>
              </div>
              <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-6">
                {trendingMovies.slice(0, 3).map((movie) => (
                  <Link
                    key={movie.id}
                    to={`/media/${movie.id}?type=movie`}
                    className="block"
                  >
                    <div className="card h-full">
                      <div className="relative aspect-video">
                        <img
                          src={
                            getImageUrl(movie.backdrop_path, "w780") ||
                            getImageUrl(movie.poster_path, "w342")
                          }
                          alt={movie.title}
                          className="w-full h-full object-cover"
                        />
                      </div>
                      <div className="p-4">
                        <h3 className="font-bold text-lg mb-2">
                          {movie.title}
                        </h3>
                        <p className="text-campfire-ash text-sm line-clamp-2">
                          {movie.overview}
                        </p>
                      </div>
                    </div>
                  </Link>
                ))}
              </div>
            </div>
          </>
        )}
      </div>
    </div>
  );
}

export default HomePage;
