import axios from 'axios';

const IMDB_API_URL = 'https://imdb.iamidiotareyoutoo.com';

export const mediaTypes = {
  MOVIE: 'movie',
  TV: 'tv',
  ALL: 'all' // Добавлено
};

function isLocalStorageAvailable() {
  try {
    const testKey = '__test__';
    localStorage.setItem(testKey, testKey);
    localStorage.removeItem(testKey);
    return true;
  } catch (e) {
    return false;
  }
}

async function searchIMDb(query, type = mediaTypes.ALL) {
  try {
    const response = await axios.get(`${IMDB_API_URL}/search`, {
      params: { q: query },
      timeout: 5000 // Добавлен таймаут
    });

    if (!response.data || !Array.isArray(response.data)) {
      return [];
    }

    return response.data
      .filter(item => {
        if (!item) return false;
        return type === mediaTypes.ALL || 
              (item.type && item.type.toLowerCase() === type);
      })
      .map(item => ({
        id: item.imdbID || '',
        title: item.title || 'Unknown',
        poster: item.poster || '',
        rating: Math.min(100, Math.max(0, parseFloat(item.rating || '0') * 10)),
        releaseDate: item.year || 'Unknown',
        type: (item.type || '').toLowerCase()
      }));
  } catch (error) {
    console.error('Error searching IMDb:', error);
    return [];
  }
}

export async function getTrendingMedia(type) {
  try {
    if (!isLocalStorageAvailable()) return [];
    
    const mediaStr = localStorage.getItem('media');
    if (!mediaStr) return [];
    
    const media = JSON.parse(mediaStr);
    if (!Array.isArray(media)) return [];
    
    return media
      .filter(item => item && item.type === type && item.trending === true)
      .slice(0, 10);
  } catch (error) {
    console.error('Error fetching trending media:', error);
    return [];
  }
}

export async function getMediaById(id) {
  try {
    if (!isLocalStorageAvailable()) return null;
    
    const mediaStr = localStorage.getItem('media');
    if (!mediaStr) return null;
    
    const media = JSON.parse(mediaStr);
    if (!Array.isArray(media)) return null;
    
    return media.find(item => item && item.id === id) || null;
  } catch (error) {
    console.error('Error fetching media:', error);
    return null;
  }
}

export async function searchMedia(query) {
  try {
    if (!query || !query.trim()) return [];
    return await searchIMDb(query, mediaTypes.ALL);
  } catch (error) {
    console.error('Error searching media:', error);
    return [];
  }
}

export async function addMedia(mediaData) {
  try {
    if (!isLocalStorageAvailable()) {
      throw new Error('Local storage is not available');
    }
    
    if (!mediaData || typeof mediaData !== 'object') {
      throw new Error('Invalid media data');
    }
    
    const mediaStr = localStorage.getItem('media') || '[]';
    const media = JSON.parse(mediaStr);
    if (!Array.isArray(media)) {
      throw new Error('Invalid media data in storage');
    }
    
    const newMedia = {
      ...mediaData,
      id: Date.now().toString(),
      createdAt: new Date().toISOString(),
      trending: Boolean(mediaData.trending),
      rating: Math.min(100, Math.max(0, Number(mediaData.rating) || 0)),
      ratingCount: Math.max(0, Number(mediaData.ratingCount) || 0)
    };
    
    media.push(newMedia);
    localStorage.setItem('media', JSON.stringify(media));
    return newMedia.id;
  } catch (error) {
    console.error('Error adding media:', error);
    throw error;
  }
}